@@ -36,9 +36,7 @@ test_that("simulation with a complete data set", {
 
 test_that("simulation with a dosing data set", {
   out1 <- mrgsim_d(mod,temp)
-  out2 <- mrgsim_q(mod,temp,stime=stime(mod))
+  out2 <- mrgsim_q(mod,temp,stime=stime(mod),simcall=1)
   expect_identical(out1,out2)
 })
 
-
-
